==> haskell-conduit-extra-1.3.0-80-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.0
id: conduit-extra-1.3.0-Eiv0jewZlXw2l4aTFErB0V
key: conduit-extra-1.3.0-Eiv0jewZlXw2l4aTFErB0V
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: faa35117e16ed457933adb05477ce5a9
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-extra-1.3.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-extra-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/conduit-extra-1.3.0
hs-libraries: HSconduit-extra-1.3.0-Eiv0jewZlXw2l4aTFErB0V
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49 base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1-BmabwSZESuG6iKDxLo0IET
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf process-1.6.3.0
    resourcet-1.2.2-1GcRGMcYBbwIukAqEHFrag stm-2.5.0.0
    streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD text-1.2.3.1
    transformers-0.5.5.0 typed-process-0.2.3.0-3rvipCUxaPzCjPaNRon0Lm
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.0-82-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.0
id: conduit-extra-1.3.0-2wMsaf55u9K2YM4obRcLES
key: conduit-extra-1.3.0-2wMsaf55u9K2YM4obRcLES
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 65a9d1dd035745d9e2693835884a1d2c
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-extra-1.3.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-extra-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/conduit-extra-1.3.0
hs-libraries: HSconduit-extra-1.3.0-2wMsaf55u9K2YM4obRcLES
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49 base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1-AZTxIDI3CJlDMLereOgNtn
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf process-1.6.3.0
    resourcet-1.2.2-1GcRGMcYBbwIukAqEHFrag stm-2.5.0.0
    streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD text-1.2.3.1
    transformers-0.5.5.0 typed-process-0.2.4.0-Fn4YjctMkMQ2zeqYXJbWzU
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
